"""
Main interface for iotanalytics service type definitions.

Usage::

    from mypy_boto3.iotanalytics.type_defs import ClientBatchPutMessageMessagesTypeDef

    data: ClientBatchPutMessageMessagesTypeDef = {...}
"""
from __future__ import annotations

from datetime import datetime
import sys
from typing import Any, Dict, List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "ClientBatchPutMessageMessagesTypeDef",
    "ClientBatchPutMessageResponsebatchPutMessageErrorEntriesTypeDef",
    "ClientBatchPutMessageResponseTypeDef",
    "ClientCreateChannelChannelStoragecustomerManagedS3TypeDef",
    "ClientCreateChannelChannelStorageTypeDef",
    "ClientCreateChannelResponseretentionPeriodTypeDef",
    "ClientCreateChannelResponseTypeDef",
    "ClientCreateChannelRetentionPeriodTypeDef",
    "ClientCreateChannelTagsTypeDef",
    "ClientCreateDatasetActionscontainerActionresourceConfigurationTypeDef",
    "ClientCreateDatasetActionscontainerActionvariablesdatasetContentVersionValueTypeDef",
    "ClientCreateDatasetActionscontainerActionvariablesoutputFileUriValueTypeDef",
    "ClientCreateDatasetActionscontainerActionvariablesTypeDef",
    "ClientCreateDatasetActionscontainerActionTypeDef",
    "ClientCreateDatasetActionsqueryActionfiltersdeltaTimeTypeDef",
    "ClientCreateDatasetActionsqueryActionfiltersTypeDef",
    "ClientCreateDatasetActionsqueryActionTypeDef",
    "ClientCreateDatasetActionsTypeDef",
    "ClientCreateDatasetContentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef",
    "ClientCreateDatasetContentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef",
    "ClientCreateDatasetContentDeliveryRulesdestinations3DestinationConfigurationTypeDef",
    "ClientCreateDatasetContentDeliveryRulesdestinationTypeDef",
    "ClientCreateDatasetContentDeliveryRulesTypeDef",
    "ClientCreateDatasetContentResponseTypeDef",
    "ClientCreateDatasetResponseretentionPeriodTypeDef",
    "ClientCreateDatasetResponseTypeDef",
    "ClientCreateDatasetRetentionPeriodTypeDef",
    "ClientCreateDatasetTagsTypeDef",
    "ClientCreateDatasetTriggersdatasetTypeDef",
    "ClientCreateDatasetTriggersscheduleTypeDef",
    "ClientCreateDatasetTriggersTypeDef",
    "ClientCreateDatasetVersioningConfigurationTypeDef",
    "ClientCreateDatastoreDatastoreStoragecustomerManagedS3TypeDef",
    "ClientCreateDatastoreDatastoreStorageTypeDef",
    "ClientCreateDatastoreResponseretentionPeriodTypeDef",
    "ClientCreateDatastoreResponseTypeDef",
    "ClientCreateDatastoreRetentionPeriodTypeDef",
    "ClientCreateDatastoreTagsTypeDef",
    "ClientCreatePipelinePipelineActivitiesaddAttributesTypeDef",
    "ClientCreatePipelinePipelineActivitieschannelTypeDef",
    "ClientCreatePipelinePipelineActivitiesdatastoreTypeDef",
    "ClientCreatePipelinePipelineActivitiesdeviceRegistryEnrichTypeDef",
    "ClientCreatePipelinePipelineActivitiesdeviceShadowEnrichTypeDef",
    "ClientCreatePipelinePipelineActivitiesfilterTypeDef",
    "ClientCreatePipelinePipelineActivitieslambdaTypeDef",
    "ClientCreatePipelinePipelineActivitiesmathTypeDef",
    "ClientCreatePipelinePipelineActivitiesremoveAttributesTypeDef",
    "ClientCreatePipelinePipelineActivitiesselectAttributesTypeDef",
    "ClientCreatePipelinePipelineActivitiesTypeDef",
    "ClientCreatePipelineResponseTypeDef",
    "ClientCreatePipelineTagsTypeDef",
    "ClientDescribeChannelResponsechannelretentionPeriodTypeDef",
    "ClientDescribeChannelResponsechannelstoragecustomerManagedS3TypeDef",
    "ClientDescribeChannelResponsechannelstorageTypeDef",
    "ClientDescribeChannelResponsechannelTypeDef",
    "ClientDescribeChannelResponsestatisticssizeTypeDef",
    "ClientDescribeChannelResponsestatisticsTypeDef",
    "ClientDescribeChannelResponseTypeDef",
    "ClientDescribeDatasetResponsedatasetactionscontainerActionresourceConfigurationTypeDef",
    "ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesdatasetContentVersionValueTypeDef",
    "ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesoutputFileUriValueTypeDef",
    "ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesTypeDef",
    "ClientDescribeDatasetResponsedatasetactionscontainerActionTypeDef",
    "ClientDescribeDatasetResponsedatasetactionsqueryActionfiltersdeltaTimeTypeDef",
    "ClientDescribeDatasetResponsedatasetactionsqueryActionfiltersTypeDef",
    "ClientDescribeDatasetResponsedatasetactionsqueryActionTypeDef",
    "ClientDescribeDatasetResponsedatasetactionsTypeDef",
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef",
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef",
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinations3DestinationConfigurationTypeDef",
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinationTypeDef",
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesTypeDef",
    "ClientDescribeDatasetResponsedatasetretentionPeriodTypeDef",
    "ClientDescribeDatasetResponsedatasettriggersdatasetTypeDef",
    "ClientDescribeDatasetResponsedatasettriggersscheduleTypeDef",
    "ClientDescribeDatasetResponsedatasettriggersTypeDef",
    "ClientDescribeDatasetResponsedatasetversioningConfigurationTypeDef",
    "ClientDescribeDatasetResponsedatasetTypeDef",
    "ClientDescribeDatasetResponseTypeDef",
    "ClientDescribeDatastoreResponsedatastoreretentionPeriodTypeDef",
    "ClientDescribeDatastoreResponsedatastorestoragecustomerManagedS3TypeDef",
    "ClientDescribeDatastoreResponsedatastorestorageTypeDef",
    "ClientDescribeDatastoreResponsedatastoreTypeDef",
    "ClientDescribeDatastoreResponsestatisticssizeTypeDef",
    "ClientDescribeDatastoreResponsestatisticsTypeDef",
    "ClientDescribeDatastoreResponseTypeDef",
    "ClientDescribeLoggingOptionsResponseloggingOptionsTypeDef",
    "ClientDescribeLoggingOptionsResponseTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesaddAttributesTypeDef",
    "ClientDescribePipelineResponsepipelineactivitieschannelTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesdatastoreTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesdeviceRegistryEnrichTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesdeviceShadowEnrichTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesfilterTypeDef",
    "ClientDescribePipelineResponsepipelineactivitieslambdaTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesmathTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesremoveAttributesTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesselectAttributesTypeDef",
    "ClientDescribePipelineResponsepipelineactivitiesTypeDef",
    "ClientDescribePipelineResponsepipelinereprocessingSummariesTypeDef",
    "ClientDescribePipelineResponsepipelineTypeDef",
    "ClientDescribePipelineResponseTypeDef",
    "ClientGetDatasetContentResponseentriesTypeDef",
    "ClientGetDatasetContentResponsestatusTypeDef",
    "ClientGetDatasetContentResponseTypeDef",
    "ClientListChannelsResponsechannelSummarieschannelStoragecustomerManagedS3TypeDef",
    "ClientListChannelsResponsechannelSummarieschannelStorageTypeDef",
    "ClientListChannelsResponsechannelSummariesTypeDef",
    "ClientListChannelsResponseTypeDef",
    "ClientListDatasetContentsResponsedatasetContentSummariesstatusTypeDef",
    "ClientListDatasetContentsResponsedatasetContentSummariesTypeDef",
    "ClientListDatasetContentsResponseTypeDef",
    "ClientListDatasetsResponsedatasetSummariesactionsTypeDef",
    "ClientListDatasetsResponsedatasetSummariestriggersdatasetTypeDef",
    "ClientListDatasetsResponsedatasetSummariestriggersscheduleTypeDef",
    "ClientListDatasetsResponsedatasetSummariestriggersTypeDef",
    "ClientListDatasetsResponsedatasetSummariesTypeDef",
    "ClientListDatasetsResponseTypeDef",
    "ClientListDatastoresResponsedatastoreSummariesdatastoreStoragecustomerManagedS3TypeDef",
    "ClientListDatastoresResponsedatastoreSummariesdatastoreStorageTypeDef",
    "ClientListDatastoresResponsedatastoreSummariesTypeDef",
    "ClientListDatastoresResponseTypeDef",
    "ClientListPipelinesResponsepipelineSummariesreprocessingSummariesTypeDef",
    "ClientListPipelinesResponsepipelineSummariesTypeDef",
    "ClientListPipelinesResponseTypeDef",
    "ClientListTagsForResourceResponsetagsTypeDef",
    "ClientListTagsForResourceResponseTypeDef",
    "ClientPutLoggingOptionsLoggingOptionsTypeDef",
    "ClientRunPipelineActivityPipelineActivityaddAttributesTypeDef",
    "ClientRunPipelineActivityPipelineActivitychannelTypeDef",
    "ClientRunPipelineActivityPipelineActivitydatastoreTypeDef",
    "ClientRunPipelineActivityPipelineActivitydeviceRegistryEnrichTypeDef",
    "ClientRunPipelineActivityPipelineActivitydeviceShadowEnrichTypeDef",
    "ClientRunPipelineActivityPipelineActivityfilterTypeDef",
    "ClientRunPipelineActivityPipelineActivitylambdaTypeDef",
    "ClientRunPipelineActivityPipelineActivitymathTypeDef",
    "ClientRunPipelineActivityPipelineActivityremoveAttributesTypeDef",
    "ClientRunPipelineActivityPipelineActivityselectAttributesTypeDef",
    "ClientRunPipelineActivityPipelineActivityTypeDef",
    "ClientRunPipelineActivityResponseTypeDef",
    "ClientSampleChannelDataResponseTypeDef",
    "ClientStartPipelineReprocessingResponseTypeDef",
    "ClientTagResourceTagsTypeDef",
    "ClientUpdateChannelChannelStoragecustomerManagedS3TypeDef",
    "ClientUpdateChannelChannelStorageTypeDef",
    "ClientUpdateChannelRetentionPeriodTypeDef",
    "ClientUpdateDatasetActionscontainerActionresourceConfigurationTypeDef",
    "ClientUpdateDatasetActionscontainerActionvariablesdatasetContentVersionValueTypeDef",
    "ClientUpdateDatasetActionscontainerActionvariablesoutputFileUriValueTypeDef",
    "ClientUpdateDatasetActionscontainerActionvariablesTypeDef",
    "ClientUpdateDatasetActionscontainerActionTypeDef",
    "ClientUpdateDatasetActionsqueryActionfiltersdeltaTimeTypeDef",
    "ClientUpdateDatasetActionsqueryActionfiltersTypeDef",
    "ClientUpdateDatasetActionsqueryActionTypeDef",
    "ClientUpdateDatasetActionsTypeDef",
    "ClientUpdateDatasetContentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef",
    "ClientUpdateDatasetContentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef",
    "ClientUpdateDatasetContentDeliveryRulesdestinations3DestinationConfigurationTypeDef",
    "ClientUpdateDatasetContentDeliveryRulesdestinationTypeDef",
    "ClientUpdateDatasetContentDeliveryRulesTypeDef",
    "ClientUpdateDatasetRetentionPeriodTypeDef",
    "ClientUpdateDatasetTriggersdatasetTypeDef",
    "ClientUpdateDatasetTriggersscheduleTypeDef",
    "ClientUpdateDatasetTriggersTypeDef",
    "ClientUpdateDatasetVersioningConfigurationTypeDef",
    "ClientUpdateDatastoreDatastoreStoragecustomerManagedS3TypeDef",
    "ClientUpdateDatastoreDatastoreStorageTypeDef",
    "ClientUpdateDatastoreRetentionPeriodTypeDef",
    "ClientUpdatePipelinePipelineActivitiesaddAttributesTypeDef",
    "ClientUpdatePipelinePipelineActivitieschannelTypeDef",
    "ClientUpdatePipelinePipelineActivitiesdatastoreTypeDef",
    "ClientUpdatePipelinePipelineActivitiesdeviceRegistryEnrichTypeDef",
    "ClientUpdatePipelinePipelineActivitiesdeviceShadowEnrichTypeDef",
    "ClientUpdatePipelinePipelineActivitiesfilterTypeDef",
    "ClientUpdatePipelinePipelineActivitieslambdaTypeDef",
    "ClientUpdatePipelinePipelineActivitiesmathTypeDef",
    "ClientUpdatePipelinePipelineActivitiesremoveAttributesTypeDef",
    "ClientUpdatePipelinePipelineActivitiesselectAttributesTypeDef",
    "ClientUpdatePipelinePipelineActivitiesTypeDef",
    "CustomerManagedChannelS3StorageSummaryTypeDef",
    "ChannelStorageSummaryTypeDef",
    "ChannelSummaryTypeDef",
    "ListChannelsResponseTypeDef",
    "DatasetContentStatusTypeDef",
    "DatasetContentSummaryTypeDef",
    "ListDatasetContentsResponseTypeDef",
    "DatasetActionSummaryTypeDef",
    "ScheduleTypeDef",
    "TriggeringDatasetTypeDef",
    "DatasetTriggerTypeDef",
    "DatasetSummaryTypeDef",
    "ListDatasetsResponseTypeDef",
    "CustomerManagedDatastoreS3StorageSummaryTypeDef",
    "DatastoreStorageSummaryTypeDef",
    "DatastoreSummaryTypeDef",
    "ListDatastoresResponseTypeDef",
    "ReprocessingSummaryTypeDef",
    "PipelineSummaryTypeDef",
    "ListPipelinesResponseTypeDef",
    "PaginatorConfigTypeDef",
)

_RequiredClientBatchPutMessageMessagesTypeDef = TypedDict(
    "_RequiredClientBatchPutMessageMessagesTypeDef", {"messageId": str}
)
_OptionalClientBatchPutMessageMessagesTypeDef = TypedDict(
    "_OptionalClientBatchPutMessageMessagesTypeDef", {"payload": bytes}, total=False
)


class ClientBatchPutMessageMessagesTypeDef(
    _RequiredClientBatchPutMessageMessagesTypeDef, _OptionalClientBatchPutMessageMessagesTypeDef
):
    pass


ClientBatchPutMessageResponsebatchPutMessageErrorEntriesTypeDef = TypedDict(
    "ClientBatchPutMessageResponsebatchPutMessageErrorEntriesTypeDef",
    {"messageId": str, "errorCode": str, "errorMessage": str},
    total=False,
)

ClientBatchPutMessageResponseTypeDef = TypedDict(
    "ClientBatchPutMessageResponseTypeDef",
    {
        "batchPutMessageErrorEntries": List[
            ClientBatchPutMessageResponsebatchPutMessageErrorEntriesTypeDef
        ]
    },
    total=False,
)

ClientCreateChannelChannelStoragecustomerManagedS3TypeDef = TypedDict(
    "ClientCreateChannelChannelStoragecustomerManagedS3TypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ClientCreateChannelChannelStorageTypeDef = TypedDict(
    "ClientCreateChannelChannelStorageTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": ClientCreateChannelChannelStoragecustomerManagedS3TypeDef,
    },
    total=False,
)

ClientCreateChannelResponseretentionPeriodTypeDef = TypedDict(
    "ClientCreateChannelResponseretentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientCreateChannelResponseTypeDef = TypedDict(
    "ClientCreateChannelResponseTypeDef",
    {
        "channelName": str,
        "channelArn": str,
        "retentionPeriod": ClientCreateChannelResponseretentionPeriodTypeDef,
    },
    total=False,
)

ClientCreateChannelRetentionPeriodTypeDef = TypedDict(
    "ClientCreateChannelRetentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

_RequiredClientCreateChannelTagsTypeDef = TypedDict(
    "_RequiredClientCreateChannelTagsTypeDef", {"key": str}
)
_OptionalClientCreateChannelTagsTypeDef = TypedDict(
    "_OptionalClientCreateChannelTagsTypeDef", {"value": str}, total=False
)


class ClientCreateChannelTagsTypeDef(
    _RequiredClientCreateChannelTagsTypeDef, _OptionalClientCreateChannelTagsTypeDef
):
    pass


ClientCreateDatasetActionscontainerActionresourceConfigurationTypeDef = TypedDict(
    "ClientCreateDatasetActionscontainerActionresourceConfigurationTypeDef",
    {"computeType": Literal["ACU_1", "ACU_2"], "volumeSizeInGB": int},
    total=False,
)

ClientCreateDatasetActionscontainerActionvariablesdatasetContentVersionValueTypeDef = TypedDict(
    "ClientCreateDatasetActionscontainerActionvariablesdatasetContentVersionValueTypeDef",
    {"datasetName": str},
    total=False,
)

ClientCreateDatasetActionscontainerActionvariablesoutputFileUriValueTypeDef = TypedDict(
    "ClientCreateDatasetActionscontainerActionvariablesoutputFileUriValueTypeDef",
    {"fileName": str},
    total=False,
)

ClientCreateDatasetActionscontainerActionvariablesTypeDef = TypedDict(
    "ClientCreateDatasetActionscontainerActionvariablesTypeDef",
    {
        "name": str,
        "stringValue": str,
        "doubleValue": float,
        "datasetContentVersionValue": ClientCreateDatasetActionscontainerActionvariablesdatasetContentVersionValueTypeDef,
        "outputFileUriValue": ClientCreateDatasetActionscontainerActionvariablesoutputFileUriValueTypeDef,
    },
    total=False,
)

ClientCreateDatasetActionscontainerActionTypeDef = TypedDict(
    "ClientCreateDatasetActionscontainerActionTypeDef",
    {
        "image": str,
        "executionRoleArn": str,
        "resourceConfiguration": ClientCreateDatasetActionscontainerActionresourceConfigurationTypeDef,
        "variables": List[ClientCreateDatasetActionscontainerActionvariablesTypeDef],
    },
    total=False,
)

ClientCreateDatasetActionsqueryActionfiltersdeltaTimeTypeDef = TypedDict(
    "ClientCreateDatasetActionsqueryActionfiltersdeltaTimeTypeDef",
    {"offsetSeconds": int, "timeExpression": str},
    total=False,
)

ClientCreateDatasetActionsqueryActionfiltersTypeDef = TypedDict(
    "ClientCreateDatasetActionsqueryActionfiltersTypeDef",
    {"deltaTime": ClientCreateDatasetActionsqueryActionfiltersdeltaTimeTypeDef},
    total=False,
)

ClientCreateDatasetActionsqueryActionTypeDef = TypedDict(
    "ClientCreateDatasetActionsqueryActionTypeDef",
    {"sqlQuery": str, "filters": List[ClientCreateDatasetActionsqueryActionfiltersTypeDef]},
    total=False,
)

ClientCreateDatasetActionsTypeDef = TypedDict(
    "ClientCreateDatasetActionsTypeDef",
    {
        "actionName": str,
        "queryAction": ClientCreateDatasetActionsqueryActionTypeDef,
        "containerAction": ClientCreateDatasetActionscontainerActionTypeDef,
    },
    total=False,
)

ClientCreateDatasetContentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef = TypedDict(
    "ClientCreateDatasetContentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef",
    {"inputName": str, "roleArn": str},
    total=False,
)

ClientCreateDatasetContentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef = TypedDict(
    "ClientCreateDatasetContentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef",
    {"tableName": str, "databaseName": str},
    total=False,
)

ClientCreateDatasetContentDeliveryRulesdestinations3DestinationConfigurationTypeDef = TypedDict(
    "ClientCreateDatasetContentDeliveryRulesdestinations3DestinationConfigurationTypeDef",
    {
        "bucket": str,
        "key": str,
        "glueConfiguration": ClientCreateDatasetContentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef,
        "roleArn": str,
    },
    total=False,
)

ClientCreateDatasetContentDeliveryRulesdestinationTypeDef = TypedDict(
    "ClientCreateDatasetContentDeliveryRulesdestinationTypeDef",
    {
        "iotEventsDestinationConfiguration": ClientCreateDatasetContentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef,
        "s3DestinationConfiguration": ClientCreateDatasetContentDeliveryRulesdestinations3DestinationConfigurationTypeDef,
    },
    total=False,
)

ClientCreateDatasetContentDeliveryRulesTypeDef = TypedDict(
    "ClientCreateDatasetContentDeliveryRulesTypeDef",
    {"entryName": str, "destination": ClientCreateDatasetContentDeliveryRulesdestinationTypeDef},
    total=False,
)

ClientCreateDatasetContentResponseTypeDef = TypedDict(
    "ClientCreateDatasetContentResponseTypeDef", {"versionId": str}, total=False
)

ClientCreateDatasetResponseretentionPeriodTypeDef = TypedDict(
    "ClientCreateDatasetResponseretentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientCreateDatasetResponseTypeDef = TypedDict(
    "ClientCreateDatasetResponseTypeDef",
    {
        "datasetName": str,
        "datasetArn": str,
        "retentionPeriod": ClientCreateDatasetResponseretentionPeriodTypeDef,
    },
    total=False,
)

ClientCreateDatasetRetentionPeriodTypeDef = TypedDict(
    "ClientCreateDatasetRetentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

_RequiredClientCreateDatasetTagsTypeDef = TypedDict(
    "_RequiredClientCreateDatasetTagsTypeDef", {"key": str}
)
_OptionalClientCreateDatasetTagsTypeDef = TypedDict(
    "_OptionalClientCreateDatasetTagsTypeDef", {"value": str}, total=False
)


class ClientCreateDatasetTagsTypeDef(
    _RequiredClientCreateDatasetTagsTypeDef, _OptionalClientCreateDatasetTagsTypeDef
):
    pass


ClientCreateDatasetTriggersdatasetTypeDef = TypedDict(
    "ClientCreateDatasetTriggersdatasetTypeDef", {"name": str}, total=False
)

ClientCreateDatasetTriggersscheduleTypeDef = TypedDict(
    "ClientCreateDatasetTriggersscheduleTypeDef", {"expression": str}, total=False
)

ClientCreateDatasetTriggersTypeDef = TypedDict(
    "ClientCreateDatasetTriggersTypeDef",
    {
        "schedule": ClientCreateDatasetTriggersscheduleTypeDef,
        "dataset": ClientCreateDatasetTriggersdatasetTypeDef,
    },
    total=False,
)

ClientCreateDatasetVersioningConfigurationTypeDef = TypedDict(
    "ClientCreateDatasetVersioningConfigurationTypeDef",
    {"unlimited": bool, "maxVersions": int},
    total=False,
)

ClientCreateDatastoreDatastoreStoragecustomerManagedS3TypeDef = TypedDict(
    "ClientCreateDatastoreDatastoreStoragecustomerManagedS3TypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ClientCreateDatastoreDatastoreStorageTypeDef = TypedDict(
    "ClientCreateDatastoreDatastoreStorageTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": ClientCreateDatastoreDatastoreStoragecustomerManagedS3TypeDef,
    },
    total=False,
)

ClientCreateDatastoreResponseretentionPeriodTypeDef = TypedDict(
    "ClientCreateDatastoreResponseretentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientCreateDatastoreResponseTypeDef = TypedDict(
    "ClientCreateDatastoreResponseTypeDef",
    {
        "datastoreName": str,
        "datastoreArn": str,
        "retentionPeriod": ClientCreateDatastoreResponseretentionPeriodTypeDef,
    },
    total=False,
)

ClientCreateDatastoreRetentionPeriodTypeDef = TypedDict(
    "ClientCreateDatastoreRetentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

_RequiredClientCreateDatastoreTagsTypeDef = TypedDict(
    "_RequiredClientCreateDatastoreTagsTypeDef", {"key": str}
)
_OptionalClientCreateDatastoreTagsTypeDef = TypedDict(
    "_OptionalClientCreateDatastoreTagsTypeDef", {"value": str}, total=False
)


class ClientCreateDatastoreTagsTypeDef(
    _RequiredClientCreateDatastoreTagsTypeDef, _OptionalClientCreateDatastoreTagsTypeDef
):
    pass


ClientCreatePipelinePipelineActivitiesaddAttributesTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesaddAttributesTypeDef",
    {"name": str, "attributes": Dict[str, str], "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitieschannelTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitieschannelTypeDef",
    {"name": str, "channelName": str, "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitiesdatastoreTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesdatastoreTypeDef",
    {"name": str, "datastoreName": str},
    total=False,
)

ClientCreatePipelinePipelineActivitiesdeviceRegistryEnrichTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesdeviceRegistryEnrichTypeDef",
    {"name": str, "attribute": str, "thingName": str, "roleArn": str, "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitiesdeviceShadowEnrichTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesdeviceShadowEnrichTypeDef",
    {"name": str, "attribute": str, "thingName": str, "roleArn": str, "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitiesfilterTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesfilterTypeDef",
    {"name": str, "filter": str, "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitieslambdaTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitieslambdaTypeDef",
    {"name": str, "lambdaName": str, "batchSize": int, "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitiesmathTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesmathTypeDef",
    {"name": str, "attribute": str, "math": str, "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitiesremoveAttributesTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesremoveAttributesTypeDef",
    {"name": str, "attributes": List[str], "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitiesselectAttributesTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesselectAttributesTypeDef",
    {"name": str, "attributes": List[str], "next": str},
    total=False,
)

ClientCreatePipelinePipelineActivitiesTypeDef = TypedDict(
    "ClientCreatePipelinePipelineActivitiesTypeDef",
    {
        "channel": ClientCreatePipelinePipelineActivitieschannelTypeDef,
        "lambda": ClientCreatePipelinePipelineActivitieslambdaTypeDef,
        "datastore": ClientCreatePipelinePipelineActivitiesdatastoreTypeDef,
        "addAttributes": ClientCreatePipelinePipelineActivitiesaddAttributesTypeDef,
        "removeAttributes": ClientCreatePipelinePipelineActivitiesremoveAttributesTypeDef,
        "selectAttributes": ClientCreatePipelinePipelineActivitiesselectAttributesTypeDef,
        "filter": ClientCreatePipelinePipelineActivitiesfilterTypeDef,
        "math": ClientCreatePipelinePipelineActivitiesmathTypeDef,
        "deviceRegistryEnrich": ClientCreatePipelinePipelineActivitiesdeviceRegistryEnrichTypeDef,
        "deviceShadowEnrich": ClientCreatePipelinePipelineActivitiesdeviceShadowEnrichTypeDef,
    },
    total=False,
)

ClientCreatePipelineResponseTypeDef = TypedDict(
    "ClientCreatePipelineResponseTypeDef", {"pipelineName": str, "pipelineArn": str}, total=False
)

_RequiredClientCreatePipelineTagsTypeDef = TypedDict(
    "_RequiredClientCreatePipelineTagsTypeDef", {"key": str}
)
_OptionalClientCreatePipelineTagsTypeDef = TypedDict(
    "_OptionalClientCreatePipelineTagsTypeDef", {"value": str}, total=False
)


class ClientCreatePipelineTagsTypeDef(
    _RequiredClientCreatePipelineTagsTypeDef, _OptionalClientCreatePipelineTagsTypeDef
):
    pass


ClientDescribeChannelResponsechannelretentionPeriodTypeDef = TypedDict(
    "ClientDescribeChannelResponsechannelretentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientDescribeChannelResponsechannelstoragecustomerManagedS3TypeDef = TypedDict(
    "ClientDescribeChannelResponsechannelstoragecustomerManagedS3TypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ClientDescribeChannelResponsechannelstorageTypeDef = TypedDict(
    "ClientDescribeChannelResponsechannelstorageTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": ClientDescribeChannelResponsechannelstoragecustomerManagedS3TypeDef,
    },
    total=False,
)

ClientDescribeChannelResponsechannelTypeDef = TypedDict(
    "ClientDescribeChannelResponsechannelTypeDef",
    {
        "name": str,
        "storage": ClientDescribeChannelResponsechannelstorageTypeDef,
        "arn": str,
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "retentionPeriod": ClientDescribeChannelResponsechannelretentionPeriodTypeDef,
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ClientDescribeChannelResponsestatisticssizeTypeDef = TypedDict(
    "ClientDescribeChannelResponsestatisticssizeTypeDef",
    {"estimatedSizeInBytes": float, "estimatedOn": datetime},
    total=False,
)

ClientDescribeChannelResponsestatisticsTypeDef = TypedDict(
    "ClientDescribeChannelResponsestatisticsTypeDef",
    {"size": ClientDescribeChannelResponsestatisticssizeTypeDef},
    total=False,
)

ClientDescribeChannelResponseTypeDef = TypedDict(
    "ClientDescribeChannelResponseTypeDef",
    {
        "channel": ClientDescribeChannelResponsechannelTypeDef,
        "statistics": ClientDescribeChannelResponsestatisticsTypeDef,
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetactionscontainerActionresourceConfigurationTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionscontainerActionresourceConfigurationTypeDef",
    {"computeType": Literal["ACU_1", "ACU_2"], "volumeSizeInGB": int},
    total=False,
)

ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesdatasetContentVersionValueTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesdatasetContentVersionValueTypeDef",
    {"datasetName": str},
    total=False,
)

ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesoutputFileUriValueTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesoutputFileUriValueTypeDef",
    {"fileName": str},
    total=False,
)

ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesTypeDef",
    {
        "name": str,
        "stringValue": str,
        "doubleValue": float,
        "datasetContentVersionValue": ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesdatasetContentVersionValueTypeDef,
        "outputFileUriValue": ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesoutputFileUriValueTypeDef,
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetactionscontainerActionTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionscontainerActionTypeDef",
    {
        "image": str,
        "executionRoleArn": str,
        "resourceConfiguration": ClientDescribeDatasetResponsedatasetactionscontainerActionresourceConfigurationTypeDef,
        "variables": List[
            ClientDescribeDatasetResponsedatasetactionscontainerActionvariablesTypeDef
        ],
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetactionsqueryActionfiltersdeltaTimeTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionsqueryActionfiltersdeltaTimeTypeDef",
    {"offsetSeconds": int, "timeExpression": str},
    total=False,
)

ClientDescribeDatasetResponsedatasetactionsqueryActionfiltersTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionsqueryActionfiltersTypeDef",
    {"deltaTime": ClientDescribeDatasetResponsedatasetactionsqueryActionfiltersdeltaTimeTypeDef},
    total=False,
)

ClientDescribeDatasetResponsedatasetactionsqueryActionTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionsqueryActionTypeDef",
    {
        "sqlQuery": str,
        "filters": List[ClientDescribeDatasetResponsedatasetactionsqueryActionfiltersTypeDef],
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetactionsTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetactionsTypeDef",
    {
        "actionName": str,
        "queryAction": ClientDescribeDatasetResponsedatasetactionsqueryActionTypeDef,
        "containerAction": ClientDescribeDatasetResponsedatasetactionscontainerActionTypeDef,
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef",
    {"inputName": str, "roleArn": str},
    total=False,
)

ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef",
    {"tableName": str, "databaseName": str},
    total=False,
)

ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinations3DestinationConfigurationTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinations3DestinationConfigurationTypeDef",
    {
        "bucket": str,
        "key": str,
        "glueConfiguration": ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef,
        "roleArn": str,
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinationTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinationTypeDef",
    {
        "iotEventsDestinationConfiguration": ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef,
        "s3DestinationConfiguration": ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinations3DestinationConfigurationTypeDef,
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetcontentDeliveryRulesTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetcontentDeliveryRulesTypeDef",
    {
        "entryName": str,
        "destination": ClientDescribeDatasetResponsedatasetcontentDeliveryRulesdestinationTypeDef,
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetretentionPeriodTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetretentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientDescribeDatasetResponsedatasettriggersdatasetTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasettriggersdatasetTypeDef", {"name": str}, total=False
)

ClientDescribeDatasetResponsedatasettriggersscheduleTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasettriggersscheduleTypeDef", {"expression": str}, total=False
)

ClientDescribeDatasetResponsedatasettriggersTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasettriggersTypeDef",
    {
        "schedule": ClientDescribeDatasetResponsedatasettriggersscheduleTypeDef,
        "dataset": ClientDescribeDatasetResponsedatasettriggersdatasetTypeDef,
    },
    total=False,
)

ClientDescribeDatasetResponsedatasetversioningConfigurationTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetversioningConfigurationTypeDef",
    {"unlimited": bool, "maxVersions": int},
    total=False,
)

ClientDescribeDatasetResponsedatasetTypeDef = TypedDict(
    "ClientDescribeDatasetResponsedatasetTypeDef",
    {
        "name": str,
        "arn": str,
        "actions": List[ClientDescribeDatasetResponsedatasetactionsTypeDef],
        "triggers": List[ClientDescribeDatasetResponsedatasettriggersTypeDef],
        "contentDeliveryRules": List[
            ClientDescribeDatasetResponsedatasetcontentDeliveryRulesTypeDef
        ],
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
        "retentionPeriod": ClientDescribeDatasetResponsedatasetretentionPeriodTypeDef,
        "versioningConfiguration": ClientDescribeDatasetResponsedatasetversioningConfigurationTypeDef,
    },
    total=False,
)

ClientDescribeDatasetResponseTypeDef = TypedDict(
    "ClientDescribeDatasetResponseTypeDef",
    {"dataset": ClientDescribeDatasetResponsedatasetTypeDef},
    total=False,
)

ClientDescribeDatastoreResponsedatastoreretentionPeriodTypeDef = TypedDict(
    "ClientDescribeDatastoreResponsedatastoreretentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientDescribeDatastoreResponsedatastorestoragecustomerManagedS3TypeDef = TypedDict(
    "ClientDescribeDatastoreResponsedatastorestoragecustomerManagedS3TypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ClientDescribeDatastoreResponsedatastorestorageTypeDef = TypedDict(
    "ClientDescribeDatastoreResponsedatastorestorageTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": ClientDescribeDatastoreResponsedatastorestoragecustomerManagedS3TypeDef,
    },
    total=False,
)

ClientDescribeDatastoreResponsedatastoreTypeDef = TypedDict(
    "ClientDescribeDatastoreResponsedatastoreTypeDef",
    {
        "name": str,
        "storage": ClientDescribeDatastoreResponsedatastorestorageTypeDef,
        "arn": str,
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "retentionPeriod": ClientDescribeDatastoreResponsedatastoreretentionPeriodTypeDef,
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ClientDescribeDatastoreResponsestatisticssizeTypeDef = TypedDict(
    "ClientDescribeDatastoreResponsestatisticssizeTypeDef",
    {"estimatedSizeInBytes": float, "estimatedOn": datetime},
    total=False,
)

ClientDescribeDatastoreResponsestatisticsTypeDef = TypedDict(
    "ClientDescribeDatastoreResponsestatisticsTypeDef",
    {"size": ClientDescribeDatastoreResponsestatisticssizeTypeDef},
    total=False,
)

ClientDescribeDatastoreResponseTypeDef = TypedDict(
    "ClientDescribeDatastoreResponseTypeDef",
    {
        "datastore": ClientDescribeDatastoreResponsedatastoreTypeDef,
        "statistics": ClientDescribeDatastoreResponsestatisticsTypeDef,
    },
    total=False,
)

ClientDescribeLoggingOptionsResponseloggingOptionsTypeDef = TypedDict(
    "ClientDescribeLoggingOptionsResponseloggingOptionsTypeDef",
    {"roleArn": str, "level": str, "enabled": bool},
    total=False,
)

ClientDescribeLoggingOptionsResponseTypeDef = TypedDict(
    "ClientDescribeLoggingOptionsResponseTypeDef",
    {"loggingOptions": ClientDescribeLoggingOptionsResponseloggingOptionsTypeDef},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesaddAttributesTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesaddAttributesTypeDef",
    {"name": str, "attributes": Dict[str, str], "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitieschannelTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitieschannelTypeDef",
    {"name": str, "channelName": str, "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesdatastoreTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesdatastoreTypeDef",
    {"name": str, "datastoreName": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesdeviceRegistryEnrichTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesdeviceRegistryEnrichTypeDef",
    {"name": str, "attribute": str, "thingName": str, "roleArn": str, "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesdeviceShadowEnrichTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesdeviceShadowEnrichTypeDef",
    {"name": str, "attribute": str, "thingName": str, "roleArn": str, "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesfilterTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesfilterTypeDef",
    {"name": str, "filter": str, "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitieslambdaTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitieslambdaTypeDef",
    {"name": str, "lambdaName": str, "batchSize": int, "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesmathTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesmathTypeDef",
    {"name": str, "attribute": str, "math": str, "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesremoveAttributesTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesremoveAttributesTypeDef",
    {"name": str, "attributes": List[str], "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesselectAttributesTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesselectAttributesTypeDef",
    {"name": str, "attributes": List[str], "next": str},
    total=False,
)

ClientDescribePipelineResponsepipelineactivitiesTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineactivitiesTypeDef",
    {
        "channel": ClientDescribePipelineResponsepipelineactivitieschannelTypeDef,
        "lambda": ClientDescribePipelineResponsepipelineactivitieslambdaTypeDef,
        "datastore": ClientDescribePipelineResponsepipelineactivitiesdatastoreTypeDef,
        "addAttributes": ClientDescribePipelineResponsepipelineactivitiesaddAttributesTypeDef,
        "removeAttributes": ClientDescribePipelineResponsepipelineactivitiesremoveAttributesTypeDef,
        "selectAttributes": ClientDescribePipelineResponsepipelineactivitiesselectAttributesTypeDef,
        "filter": ClientDescribePipelineResponsepipelineactivitiesfilterTypeDef,
        "math": ClientDescribePipelineResponsepipelineactivitiesmathTypeDef,
        "deviceRegistryEnrich": ClientDescribePipelineResponsepipelineactivitiesdeviceRegistryEnrichTypeDef,
        "deviceShadowEnrich": ClientDescribePipelineResponsepipelineactivitiesdeviceShadowEnrichTypeDef,
    },
    total=False,
)

ClientDescribePipelineResponsepipelinereprocessingSummariesTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelinereprocessingSummariesTypeDef",
    {
        "id": str,
        "status": Literal["RUNNING", "SUCCEEDED", "CANCELLED", "FAILED"],
        "creationTime": datetime,
    },
    total=False,
)

ClientDescribePipelineResponsepipelineTypeDef = TypedDict(
    "ClientDescribePipelineResponsepipelineTypeDef",
    {
        "name": str,
        "arn": str,
        "activities": List[ClientDescribePipelineResponsepipelineactivitiesTypeDef],
        "reprocessingSummaries": List[
            ClientDescribePipelineResponsepipelinereprocessingSummariesTypeDef
        ],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ClientDescribePipelineResponseTypeDef = TypedDict(
    "ClientDescribePipelineResponseTypeDef",
    {"pipeline": ClientDescribePipelineResponsepipelineTypeDef},
    total=False,
)

ClientGetDatasetContentResponseentriesTypeDef = TypedDict(
    "ClientGetDatasetContentResponseentriesTypeDef", {"entryName": str, "dataURI": str}, total=False
)

ClientGetDatasetContentResponsestatusTypeDef = TypedDict(
    "ClientGetDatasetContentResponsestatusTypeDef",
    {"state": Literal["CREATING", "SUCCEEDED", "FAILED"], "reason": str},
    total=False,
)

ClientGetDatasetContentResponseTypeDef = TypedDict(
    "ClientGetDatasetContentResponseTypeDef",
    {
        "entries": List[ClientGetDatasetContentResponseentriesTypeDef],
        "timestamp": datetime,
        "status": ClientGetDatasetContentResponsestatusTypeDef,
    },
    total=False,
)

ClientListChannelsResponsechannelSummarieschannelStoragecustomerManagedS3TypeDef = TypedDict(
    "ClientListChannelsResponsechannelSummarieschannelStoragecustomerManagedS3TypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ClientListChannelsResponsechannelSummarieschannelStorageTypeDef = TypedDict(
    "ClientListChannelsResponsechannelSummarieschannelStorageTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": ClientListChannelsResponsechannelSummarieschannelStoragecustomerManagedS3TypeDef,
    },
    total=False,
)

ClientListChannelsResponsechannelSummariesTypeDef = TypedDict(
    "ClientListChannelsResponsechannelSummariesTypeDef",
    {
        "channelName": str,
        "channelStorage": ClientListChannelsResponsechannelSummarieschannelStorageTypeDef,
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ClientListChannelsResponseTypeDef = TypedDict(
    "ClientListChannelsResponseTypeDef",
    {"channelSummaries": List[ClientListChannelsResponsechannelSummariesTypeDef], "nextToken": str},
    total=False,
)

ClientListDatasetContentsResponsedatasetContentSummariesstatusTypeDef = TypedDict(
    "ClientListDatasetContentsResponsedatasetContentSummariesstatusTypeDef",
    {"state": Literal["CREATING", "SUCCEEDED", "FAILED"], "reason": str},
    total=False,
)

ClientListDatasetContentsResponsedatasetContentSummariesTypeDef = TypedDict(
    "ClientListDatasetContentsResponsedatasetContentSummariesTypeDef",
    {
        "version": str,
        "status": ClientListDatasetContentsResponsedatasetContentSummariesstatusTypeDef,
        "creationTime": datetime,
        "scheduleTime": datetime,
        "completionTime": datetime,
    },
    total=False,
)

ClientListDatasetContentsResponseTypeDef = TypedDict(
    "ClientListDatasetContentsResponseTypeDef",
    {
        "datasetContentSummaries": List[
            ClientListDatasetContentsResponsedatasetContentSummariesTypeDef
        ],
        "nextToken": str,
    },
    total=False,
)

ClientListDatasetsResponsedatasetSummariesactionsTypeDef = TypedDict(
    "ClientListDatasetsResponsedatasetSummariesactionsTypeDef",
    {"actionName": str, "actionType": Literal["QUERY", "CONTAINER"]},
    total=False,
)

ClientListDatasetsResponsedatasetSummariestriggersdatasetTypeDef = TypedDict(
    "ClientListDatasetsResponsedatasetSummariestriggersdatasetTypeDef", {"name": str}, total=False
)

ClientListDatasetsResponsedatasetSummariestriggersscheduleTypeDef = TypedDict(
    "ClientListDatasetsResponsedatasetSummariestriggersscheduleTypeDef",
    {"expression": str},
    total=False,
)

ClientListDatasetsResponsedatasetSummariestriggersTypeDef = TypedDict(
    "ClientListDatasetsResponsedatasetSummariestriggersTypeDef",
    {
        "schedule": ClientListDatasetsResponsedatasetSummariestriggersscheduleTypeDef,
        "dataset": ClientListDatasetsResponsedatasetSummariestriggersdatasetTypeDef,
    },
    total=False,
)

ClientListDatasetsResponsedatasetSummariesTypeDef = TypedDict(
    "ClientListDatasetsResponsedatasetSummariesTypeDef",
    {
        "datasetName": str,
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
        "triggers": List[ClientListDatasetsResponsedatasetSummariestriggersTypeDef],
        "actions": List[ClientListDatasetsResponsedatasetSummariesactionsTypeDef],
    },
    total=False,
)

ClientListDatasetsResponseTypeDef = TypedDict(
    "ClientListDatasetsResponseTypeDef",
    {"datasetSummaries": List[ClientListDatasetsResponsedatasetSummariesTypeDef], "nextToken": str},
    total=False,
)

ClientListDatastoresResponsedatastoreSummariesdatastoreStoragecustomerManagedS3TypeDef = TypedDict(
    "ClientListDatastoresResponsedatastoreSummariesdatastoreStoragecustomerManagedS3TypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ClientListDatastoresResponsedatastoreSummariesdatastoreStorageTypeDef = TypedDict(
    "ClientListDatastoresResponsedatastoreSummariesdatastoreStorageTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": ClientListDatastoresResponsedatastoreSummariesdatastoreStoragecustomerManagedS3TypeDef,
    },
    total=False,
)

ClientListDatastoresResponsedatastoreSummariesTypeDef = TypedDict(
    "ClientListDatastoresResponsedatastoreSummariesTypeDef",
    {
        "datastoreName": str,
        "datastoreStorage": ClientListDatastoresResponsedatastoreSummariesdatastoreStorageTypeDef,
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ClientListDatastoresResponseTypeDef = TypedDict(
    "ClientListDatastoresResponseTypeDef",
    {
        "datastoreSummaries": List[ClientListDatastoresResponsedatastoreSummariesTypeDef],
        "nextToken": str,
    },
    total=False,
)

ClientListPipelinesResponsepipelineSummariesreprocessingSummariesTypeDef = TypedDict(
    "ClientListPipelinesResponsepipelineSummariesreprocessingSummariesTypeDef",
    {
        "id": str,
        "status": Literal["RUNNING", "SUCCEEDED", "CANCELLED", "FAILED"],
        "creationTime": datetime,
    },
    total=False,
)

ClientListPipelinesResponsepipelineSummariesTypeDef = TypedDict(
    "ClientListPipelinesResponsepipelineSummariesTypeDef",
    {
        "pipelineName": str,
        "reprocessingSummaries": List[
            ClientListPipelinesResponsepipelineSummariesreprocessingSummariesTypeDef
        ],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ClientListPipelinesResponseTypeDef = TypedDict(
    "ClientListPipelinesResponseTypeDef",
    {
        "pipelineSummaries": List[ClientListPipelinesResponsepipelineSummariesTypeDef],
        "nextToken": str,
    },
    total=False,
)

ClientListTagsForResourceResponsetagsTypeDef = TypedDict(
    "ClientListTagsForResourceResponsetagsTypeDef", {"key": str, "value": str}, total=False
)

ClientListTagsForResourceResponseTypeDef = TypedDict(
    "ClientListTagsForResourceResponseTypeDef",
    {"tags": List[ClientListTagsForResourceResponsetagsTypeDef]},
    total=False,
)

_RequiredClientPutLoggingOptionsLoggingOptionsTypeDef = TypedDict(
    "_RequiredClientPutLoggingOptionsLoggingOptionsTypeDef", {"roleArn": str}
)
_OptionalClientPutLoggingOptionsLoggingOptionsTypeDef = TypedDict(
    "_OptionalClientPutLoggingOptionsLoggingOptionsTypeDef",
    {"level": str, "enabled": bool},
    total=False,
)


class ClientPutLoggingOptionsLoggingOptionsTypeDef(
    _RequiredClientPutLoggingOptionsLoggingOptionsTypeDef,
    _OptionalClientPutLoggingOptionsLoggingOptionsTypeDef,
):
    pass


ClientRunPipelineActivityPipelineActivityaddAttributesTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivityaddAttributesTypeDef",
    {"name": str, "attributes": Dict[str, str], "next": str},
    total=False,
)

_RequiredClientRunPipelineActivityPipelineActivitychannelTypeDef = TypedDict(
    "_RequiredClientRunPipelineActivityPipelineActivitychannelTypeDef", {"name": str}
)
_OptionalClientRunPipelineActivityPipelineActivitychannelTypeDef = TypedDict(
    "_OptionalClientRunPipelineActivityPipelineActivitychannelTypeDef",
    {"channelName": str, "next": str},
    total=False,
)


class ClientRunPipelineActivityPipelineActivitychannelTypeDef(
    _RequiredClientRunPipelineActivityPipelineActivitychannelTypeDef,
    _OptionalClientRunPipelineActivityPipelineActivitychannelTypeDef,
):
    pass


ClientRunPipelineActivityPipelineActivitydatastoreTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivitydatastoreTypeDef",
    {"name": str, "datastoreName": str},
    total=False,
)

ClientRunPipelineActivityPipelineActivitydeviceRegistryEnrichTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivitydeviceRegistryEnrichTypeDef",
    {"name": str, "attribute": str, "thingName": str, "roleArn": str, "next": str},
    total=False,
)

ClientRunPipelineActivityPipelineActivitydeviceShadowEnrichTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivitydeviceShadowEnrichTypeDef",
    {"name": str, "attribute": str, "thingName": str, "roleArn": str, "next": str},
    total=False,
)

ClientRunPipelineActivityPipelineActivityfilterTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivityfilterTypeDef",
    {"name": str, "filter": str, "next": str},
    total=False,
)

ClientRunPipelineActivityPipelineActivitylambdaTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivitylambdaTypeDef",
    {"name": str, "lambdaName": str, "batchSize": int, "next": str},
    total=False,
)

ClientRunPipelineActivityPipelineActivitymathTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivitymathTypeDef",
    {"name": str, "attribute": str, "math": str, "next": str},
    total=False,
)

ClientRunPipelineActivityPipelineActivityremoveAttributesTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivityremoveAttributesTypeDef",
    {"name": str, "attributes": List[str], "next": str},
    total=False,
)

ClientRunPipelineActivityPipelineActivityselectAttributesTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivityselectAttributesTypeDef",
    {"name": str, "attributes": List[str], "next": str},
    total=False,
)

ClientRunPipelineActivityPipelineActivityTypeDef = TypedDict(
    "ClientRunPipelineActivityPipelineActivityTypeDef",
    {
        "channel": ClientRunPipelineActivityPipelineActivitychannelTypeDef,
        "lambda": ClientRunPipelineActivityPipelineActivitylambdaTypeDef,
        "datastore": ClientRunPipelineActivityPipelineActivitydatastoreTypeDef,
        "addAttributes": ClientRunPipelineActivityPipelineActivityaddAttributesTypeDef,
        "removeAttributes": ClientRunPipelineActivityPipelineActivityremoveAttributesTypeDef,
        "selectAttributes": ClientRunPipelineActivityPipelineActivityselectAttributesTypeDef,
        "filter": ClientRunPipelineActivityPipelineActivityfilterTypeDef,
        "math": ClientRunPipelineActivityPipelineActivitymathTypeDef,
        "deviceRegistryEnrich": ClientRunPipelineActivityPipelineActivitydeviceRegistryEnrichTypeDef,
        "deviceShadowEnrich": ClientRunPipelineActivityPipelineActivitydeviceShadowEnrichTypeDef,
    },
    total=False,
)

ClientRunPipelineActivityResponseTypeDef = TypedDict(
    "ClientRunPipelineActivityResponseTypeDef",
    {"payloads": List[bytes], "logResult": str},
    total=False,
)

ClientSampleChannelDataResponseTypeDef = TypedDict(
    "ClientSampleChannelDataResponseTypeDef", {"payloads": List[bytes]}, total=False
)

ClientStartPipelineReprocessingResponseTypeDef = TypedDict(
    "ClientStartPipelineReprocessingResponseTypeDef", {"reprocessingId": str}, total=False
)

_RequiredClientTagResourceTagsTypeDef = TypedDict(
    "_RequiredClientTagResourceTagsTypeDef", {"key": str}
)
_OptionalClientTagResourceTagsTypeDef = TypedDict(
    "_OptionalClientTagResourceTagsTypeDef", {"value": str}, total=False
)


class ClientTagResourceTagsTypeDef(
    _RequiredClientTagResourceTagsTypeDef, _OptionalClientTagResourceTagsTypeDef
):
    pass


ClientUpdateChannelChannelStoragecustomerManagedS3TypeDef = TypedDict(
    "ClientUpdateChannelChannelStoragecustomerManagedS3TypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ClientUpdateChannelChannelStorageTypeDef = TypedDict(
    "ClientUpdateChannelChannelStorageTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": ClientUpdateChannelChannelStoragecustomerManagedS3TypeDef,
    },
    total=False,
)

ClientUpdateChannelRetentionPeriodTypeDef = TypedDict(
    "ClientUpdateChannelRetentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientUpdateDatasetActionscontainerActionresourceConfigurationTypeDef = TypedDict(
    "ClientUpdateDatasetActionscontainerActionresourceConfigurationTypeDef",
    {"computeType": Literal["ACU_1", "ACU_2"], "volumeSizeInGB": int},
    total=False,
)

ClientUpdateDatasetActionscontainerActionvariablesdatasetContentVersionValueTypeDef = TypedDict(
    "ClientUpdateDatasetActionscontainerActionvariablesdatasetContentVersionValueTypeDef",
    {"datasetName": str},
    total=False,
)

ClientUpdateDatasetActionscontainerActionvariablesoutputFileUriValueTypeDef = TypedDict(
    "ClientUpdateDatasetActionscontainerActionvariablesoutputFileUriValueTypeDef",
    {"fileName": str},
    total=False,
)

ClientUpdateDatasetActionscontainerActionvariablesTypeDef = TypedDict(
    "ClientUpdateDatasetActionscontainerActionvariablesTypeDef",
    {
        "name": str,
        "stringValue": str,
        "doubleValue": float,
        "datasetContentVersionValue": ClientUpdateDatasetActionscontainerActionvariablesdatasetContentVersionValueTypeDef,
        "outputFileUriValue": ClientUpdateDatasetActionscontainerActionvariablesoutputFileUriValueTypeDef,
    },
    total=False,
)

ClientUpdateDatasetActionscontainerActionTypeDef = TypedDict(
    "ClientUpdateDatasetActionscontainerActionTypeDef",
    {
        "image": str,
        "executionRoleArn": str,
        "resourceConfiguration": ClientUpdateDatasetActionscontainerActionresourceConfigurationTypeDef,
        "variables": List[ClientUpdateDatasetActionscontainerActionvariablesTypeDef],
    },
    total=False,
)

ClientUpdateDatasetActionsqueryActionfiltersdeltaTimeTypeDef = TypedDict(
    "ClientUpdateDatasetActionsqueryActionfiltersdeltaTimeTypeDef",
    {"offsetSeconds": int, "timeExpression": str},
    total=False,
)

ClientUpdateDatasetActionsqueryActionfiltersTypeDef = TypedDict(
    "ClientUpdateDatasetActionsqueryActionfiltersTypeDef",
    {"deltaTime": ClientUpdateDatasetActionsqueryActionfiltersdeltaTimeTypeDef},
    total=False,
)

ClientUpdateDatasetActionsqueryActionTypeDef = TypedDict(
    "ClientUpdateDatasetActionsqueryActionTypeDef",
    {"sqlQuery": str, "filters": List[ClientUpdateDatasetActionsqueryActionfiltersTypeDef]},
    total=False,
)

ClientUpdateDatasetActionsTypeDef = TypedDict(
    "ClientUpdateDatasetActionsTypeDef",
    {
        "actionName": str,
        "queryAction": ClientUpdateDatasetActionsqueryActionTypeDef,
        "containerAction": ClientUpdateDatasetActionscontainerActionTypeDef,
    },
    total=False,
)

ClientUpdateDatasetContentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef = TypedDict(
    "ClientUpdateDatasetContentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef",
    {"inputName": str, "roleArn": str},
    total=False,
)

ClientUpdateDatasetContentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef = TypedDict(
    "ClientUpdateDatasetContentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef",
    {"tableName": str, "databaseName": str},
    total=False,
)

ClientUpdateDatasetContentDeliveryRulesdestinations3DestinationConfigurationTypeDef = TypedDict(
    "ClientUpdateDatasetContentDeliveryRulesdestinations3DestinationConfigurationTypeDef",
    {
        "bucket": str,
        "key": str,
        "glueConfiguration": ClientUpdateDatasetContentDeliveryRulesdestinations3DestinationConfigurationglueConfigurationTypeDef,
        "roleArn": str,
    },
    total=False,
)

ClientUpdateDatasetContentDeliveryRulesdestinationTypeDef = TypedDict(
    "ClientUpdateDatasetContentDeliveryRulesdestinationTypeDef",
    {
        "iotEventsDestinationConfiguration": ClientUpdateDatasetContentDeliveryRulesdestinationiotEventsDestinationConfigurationTypeDef,
        "s3DestinationConfiguration": ClientUpdateDatasetContentDeliveryRulesdestinations3DestinationConfigurationTypeDef,
    },
    total=False,
)

ClientUpdateDatasetContentDeliveryRulesTypeDef = TypedDict(
    "ClientUpdateDatasetContentDeliveryRulesTypeDef",
    {"entryName": str, "destination": ClientUpdateDatasetContentDeliveryRulesdestinationTypeDef},
    total=False,
)

ClientUpdateDatasetRetentionPeriodTypeDef = TypedDict(
    "ClientUpdateDatasetRetentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientUpdateDatasetTriggersdatasetTypeDef = TypedDict(
    "ClientUpdateDatasetTriggersdatasetTypeDef", {"name": str}, total=False
)

ClientUpdateDatasetTriggersscheduleTypeDef = TypedDict(
    "ClientUpdateDatasetTriggersscheduleTypeDef", {"expression": str}, total=False
)

ClientUpdateDatasetTriggersTypeDef = TypedDict(
    "ClientUpdateDatasetTriggersTypeDef",
    {
        "schedule": ClientUpdateDatasetTriggersscheduleTypeDef,
        "dataset": ClientUpdateDatasetTriggersdatasetTypeDef,
    },
    total=False,
)

ClientUpdateDatasetVersioningConfigurationTypeDef = TypedDict(
    "ClientUpdateDatasetVersioningConfigurationTypeDef",
    {"unlimited": bool, "maxVersions": int},
    total=False,
)

ClientUpdateDatastoreDatastoreStoragecustomerManagedS3TypeDef = TypedDict(
    "ClientUpdateDatastoreDatastoreStoragecustomerManagedS3TypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ClientUpdateDatastoreDatastoreStorageTypeDef = TypedDict(
    "ClientUpdateDatastoreDatastoreStorageTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": ClientUpdateDatastoreDatastoreStoragecustomerManagedS3TypeDef,
    },
    total=False,
)

ClientUpdateDatastoreRetentionPeriodTypeDef = TypedDict(
    "ClientUpdateDatastoreRetentionPeriodTypeDef",
    {"unlimited": bool, "numberOfDays": int},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesaddAttributesTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesaddAttributesTypeDef",
    {"name": str, "attributes": Dict[str, str], "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitieschannelTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitieschannelTypeDef",
    {"name": str, "channelName": str, "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesdatastoreTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesdatastoreTypeDef",
    {"name": str, "datastoreName": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesdeviceRegistryEnrichTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesdeviceRegistryEnrichTypeDef",
    {"name": str, "attribute": str, "thingName": str, "roleArn": str, "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesdeviceShadowEnrichTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesdeviceShadowEnrichTypeDef",
    {"name": str, "attribute": str, "thingName": str, "roleArn": str, "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesfilterTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesfilterTypeDef",
    {"name": str, "filter": str, "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitieslambdaTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitieslambdaTypeDef",
    {"name": str, "lambdaName": str, "batchSize": int, "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesmathTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesmathTypeDef",
    {"name": str, "attribute": str, "math": str, "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesremoveAttributesTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesremoveAttributesTypeDef",
    {"name": str, "attributes": List[str], "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesselectAttributesTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesselectAttributesTypeDef",
    {"name": str, "attributes": List[str], "next": str},
    total=False,
)

ClientUpdatePipelinePipelineActivitiesTypeDef = TypedDict(
    "ClientUpdatePipelinePipelineActivitiesTypeDef",
    {
        "channel": ClientUpdatePipelinePipelineActivitieschannelTypeDef,
        "lambda": ClientUpdatePipelinePipelineActivitieslambdaTypeDef,
        "datastore": ClientUpdatePipelinePipelineActivitiesdatastoreTypeDef,
        "addAttributes": ClientUpdatePipelinePipelineActivitiesaddAttributesTypeDef,
        "removeAttributes": ClientUpdatePipelinePipelineActivitiesremoveAttributesTypeDef,
        "selectAttributes": ClientUpdatePipelinePipelineActivitiesselectAttributesTypeDef,
        "filter": ClientUpdatePipelinePipelineActivitiesfilterTypeDef,
        "math": ClientUpdatePipelinePipelineActivitiesmathTypeDef,
        "deviceRegistryEnrich": ClientUpdatePipelinePipelineActivitiesdeviceRegistryEnrichTypeDef,
        "deviceShadowEnrich": ClientUpdatePipelinePipelineActivitiesdeviceShadowEnrichTypeDef,
    },
    total=False,
)

CustomerManagedChannelS3StorageSummaryTypeDef = TypedDict(
    "CustomerManagedChannelS3StorageSummaryTypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

ChannelStorageSummaryTypeDef = TypedDict(
    "ChannelStorageSummaryTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": CustomerManagedChannelS3StorageSummaryTypeDef,
    },
    total=False,
)

ChannelSummaryTypeDef = TypedDict(
    "ChannelSummaryTypeDef",
    {
        "channelName": str,
        "channelStorage": ChannelStorageSummaryTypeDef,
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ListChannelsResponseTypeDef = TypedDict(
    "ListChannelsResponseTypeDef",
    {"channelSummaries": List[ChannelSummaryTypeDef], "nextToken": str},
    total=False,
)

DatasetContentStatusTypeDef = TypedDict(
    "DatasetContentStatusTypeDef",
    {"state": Literal["CREATING", "SUCCEEDED", "FAILED"], "reason": str},
    total=False,
)

DatasetContentSummaryTypeDef = TypedDict(
    "DatasetContentSummaryTypeDef",
    {
        "version": str,
        "status": DatasetContentStatusTypeDef,
        "creationTime": datetime,
        "scheduleTime": datetime,
        "completionTime": datetime,
    },
    total=False,
)

ListDatasetContentsResponseTypeDef = TypedDict(
    "ListDatasetContentsResponseTypeDef",
    {"datasetContentSummaries": List[DatasetContentSummaryTypeDef], "nextToken": str},
    total=False,
)

DatasetActionSummaryTypeDef = TypedDict(
    "DatasetActionSummaryTypeDef",
    {"actionName": str, "actionType": Literal["QUERY", "CONTAINER"]},
    total=False,
)

ScheduleTypeDef = TypedDict("ScheduleTypeDef", {"expression": str}, total=False)

TriggeringDatasetTypeDef = TypedDict("TriggeringDatasetTypeDef", {"name": str})

DatasetTriggerTypeDef = TypedDict(
    "DatasetTriggerTypeDef",
    {"schedule": ScheduleTypeDef, "dataset": TriggeringDatasetTypeDef},
    total=False,
)

DatasetSummaryTypeDef = TypedDict(
    "DatasetSummaryTypeDef",
    {
        "datasetName": str,
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
        "triggers": List[DatasetTriggerTypeDef],
        "actions": List[DatasetActionSummaryTypeDef],
    },
    total=False,
)

ListDatasetsResponseTypeDef = TypedDict(
    "ListDatasetsResponseTypeDef",
    {"datasetSummaries": List[DatasetSummaryTypeDef], "nextToken": str},
    total=False,
)

CustomerManagedDatastoreS3StorageSummaryTypeDef = TypedDict(
    "CustomerManagedDatastoreS3StorageSummaryTypeDef",
    {"bucket": str, "keyPrefix": str, "roleArn": str},
    total=False,
)

DatastoreStorageSummaryTypeDef = TypedDict(
    "DatastoreStorageSummaryTypeDef",
    {
        "serviceManagedS3": Dict[str, Any],
        "customerManagedS3": CustomerManagedDatastoreS3StorageSummaryTypeDef,
    },
    total=False,
)

DatastoreSummaryTypeDef = TypedDict(
    "DatastoreSummaryTypeDef",
    {
        "datastoreName": str,
        "datastoreStorage": DatastoreStorageSummaryTypeDef,
        "status": Literal["CREATING", "ACTIVE", "DELETING"],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ListDatastoresResponseTypeDef = TypedDict(
    "ListDatastoresResponseTypeDef",
    {"datastoreSummaries": List[DatastoreSummaryTypeDef], "nextToken": str},
    total=False,
)

ReprocessingSummaryTypeDef = TypedDict(
    "ReprocessingSummaryTypeDef",
    {
        "id": str,
        "status": Literal["RUNNING", "SUCCEEDED", "CANCELLED", "FAILED"],
        "creationTime": datetime,
    },
    total=False,
)

PipelineSummaryTypeDef = TypedDict(
    "PipelineSummaryTypeDef",
    {
        "pipelineName": str,
        "reprocessingSummaries": List[ReprocessingSummaryTypeDef],
        "creationTime": datetime,
        "lastUpdateTime": datetime,
    },
    total=False,
)

ListPipelinesResponseTypeDef = TypedDict(
    "ListPipelinesResponseTypeDef",
    {"pipelineSummaries": List[PipelineSummaryTypeDef], "nextToken": str},
    total=False,
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
)



"""
Main interface for iotanalytics service client paginators.

Usage::

    import boto3
    from mypy_boto3.iotanalytics import (
        ListChannelsPaginator,
        ListDatasetContentsPaginator,
        ListDatasetsPaginator,
        ListDatastoresPaginator,
        ListPipelinesPaginator,
    )

    client: IoTAnalyticsClient = boto3.client("iotanalytics")

    list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
    list_dataset_contents_paginator: ListDatasetContentsPaginator = client.get_paginator("list_dataset_contents")
    list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
    list_datastores_paginator: ListDatastoresPaginator = client.get_paginator("list_datastores")
    list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
"""
# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
from __future__ import annotations

from datetime import datetime
from typing import Generator
from botocore.paginate import Paginator as Boto3Paginator
from mypy_boto3_iotanalytics.type_defs import (
    ListChannelsResponseTypeDef,
    ListDatasetContentsResponseTypeDef,
    ListDatasetsResponseTypeDef,
    ListDatastoresResponseTypeDef,
    ListPipelinesResponseTypeDef,
    PaginatorConfigTypeDef,
)


__all__ = (
    "ListChannelsPaginator",
    "ListDatasetContentsPaginator",
    "ListDatasetsPaginator",
    "ListDatastoresPaginator",
    "ListPipelinesPaginator",
)


class ListChannelsPaginator(Boto3Paginator):
    """
    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Generator[ListChannelsResponseTypeDef, None, None]:
        """
        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels.paginate)
        """


class ListDatasetContentsPaginator(Boto3Paginator):
    """
    [Paginator.ListDatasetContents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
    """

    def paginate(
        self,
        datasetName: str,
        scheduledOnOrAfter: datetime = None,
        scheduledBefore: datetime = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Generator[ListDatasetContentsResponseTypeDef, None, None]:
        """
        [ListDatasetContents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents.paginate)
        """


class ListDatasetsPaginator(Boto3Paginator):
    """
    [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Generator[ListDatasetsResponseTypeDef, None, None]:
        """
        [ListDatasets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets.paginate)
        """


class ListDatastoresPaginator(Boto3Paginator):
    """
    [Paginator.ListDatastores documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Generator[ListDatastoresResponseTypeDef, None, None]:
        """
        [ListDatastores.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores.paginate)
        """


class ListPipelinesPaginator(Boto3Paginator):
    """
    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Generator[ListPipelinesResponseTypeDef, None, None]:
        """
        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines.paginate)
        """



"""
Main interface for iotanalytics service client

Usage::

    import boto3
    from mypy_boto3.iotanalytics import IoTAnalyticsClient

    session = boto3.Session()

    client: IoTAnalyticsClient = boto3.client("iotanalytics")
    session_client: IoTAnalyticsClient = session.client("iotanalytics")
"""
# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
from __future__ import annotations

from datetime import datetime
import sys
from typing import Any, Dict, List, overload
from botocore.exceptions import ClientError as Boto3ClientError

# pylint: disable=import-self
import mypy_boto3_iotanalytics.client as client_scope

# pylint: disable=import-self
import mypy_boto3_iotanalytics.paginator as paginator_scope
from mypy_boto3_iotanalytics.type_defs import (
    ClientBatchPutMessageMessagesTypeDef,
    ClientBatchPutMessageResponseTypeDef,
    ClientCreateChannelChannelStorageTypeDef,
    ClientCreateChannelResponseTypeDef,
    ClientCreateChannelRetentionPeriodTypeDef,
    ClientCreateChannelTagsTypeDef,
    ClientCreateDatasetActionsTypeDef,
    ClientCreateDatasetContentDeliveryRulesTypeDef,
    ClientCreateDatasetContentResponseTypeDef,
    ClientCreateDatasetResponseTypeDef,
    ClientCreateDatasetRetentionPeriodTypeDef,
    ClientCreateDatasetTagsTypeDef,
    ClientCreateDatasetTriggersTypeDef,
    ClientCreateDatasetVersioningConfigurationTypeDef,
    ClientCreateDatastoreDatastoreStorageTypeDef,
    ClientCreateDatastoreResponseTypeDef,
    ClientCreateDatastoreRetentionPeriodTypeDef,
    ClientCreateDatastoreTagsTypeDef,
    ClientCreatePipelinePipelineActivitiesTypeDef,
    ClientCreatePipelineResponseTypeDef,
    ClientCreatePipelineTagsTypeDef,
    ClientDescribeChannelResponseTypeDef,
    ClientDescribeDatasetResponseTypeDef,
    ClientDescribeDatastoreResponseTypeDef,
    ClientDescribeLoggingOptionsResponseTypeDef,
    ClientDescribePipelineResponseTypeDef,
    ClientGetDatasetContentResponseTypeDef,
    ClientListChannelsResponseTypeDef,
    ClientListDatasetContentsResponseTypeDef,
    ClientListDatasetsResponseTypeDef,
    ClientListDatastoresResponseTypeDef,
    ClientListPipelinesResponseTypeDef,
    ClientListTagsForResourceResponseTypeDef,
    ClientPutLoggingOptionsLoggingOptionsTypeDef,
    ClientRunPipelineActivityPipelineActivityTypeDef,
    ClientRunPipelineActivityResponseTypeDef,
    ClientSampleChannelDataResponseTypeDef,
    ClientStartPipelineReprocessingResponseTypeDef,
    ClientTagResourceTagsTypeDef,
    ClientUpdateChannelChannelStorageTypeDef,
    ClientUpdateChannelRetentionPeriodTypeDef,
    ClientUpdateDatasetActionsTypeDef,
    ClientUpdateDatasetContentDeliveryRulesTypeDef,
    ClientUpdateDatasetRetentionPeriodTypeDef,
    ClientUpdateDatasetTriggersTypeDef,
    ClientUpdateDatasetVersioningConfigurationTypeDef,
    ClientUpdateDatastoreDatastoreStorageTypeDef,
    ClientUpdateDatastoreRetentionPeriodTypeDef,
    ClientUpdatePipelinePipelineActivitiesTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("IoTAnalyticsClient",)


class IoTAnalyticsClient:
    """
    [IoTAnalytics.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client)
    """

    exceptions: client_scope.Exceptions

    def batch_put_message(
        self, channelName: str, messages: List[ClientBatchPutMessageMessagesTypeDef]
    ) -> ClientBatchPutMessageResponseTypeDef:
        """
        [Client.batch_put_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.batch_put_message)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.can_paginate)
        """

    def cancel_pipeline_reprocessing(
        self, pipelineName: str, reprocessingId: str
    ) -> Dict[str, Any]:
        """
        [Client.cancel_pipeline_reprocessing documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.cancel_pipeline_reprocessing)
        """

    def create_channel(
        self,
        channelName: str,
        channelStorage: ClientCreateChannelChannelStorageTypeDef = None,
        retentionPeriod: ClientCreateChannelRetentionPeriodTypeDef = None,
        tags: List[ClientCreateChannelTagsTypeDef] = None,
    ) -> ClientCreateChannelResponseTypeDef:
        """
        [Client.create_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.create_channel)
        """

    def create_dataset(
        self,
        datasetName: str,
        actions: List[ClientCreateDatasetActionsTypeDef],
        triggers: List[ClientCreateDatasetTriggersTypeDef] = None,
        contentDeliveryRules: List[ClientCreateDatasetContentDeliveryRulesTypeDef] = None,
        retentionPeriod: ClientCreateDatasetRetentionPeriodTypeDef = None,
        versioningConfiguration: ClientCreateDatasetVersioningConfigurationTypeDef = None,
        tags: List[ClientCreateDatasetTagsTypeDef] = None,
    ) -> ClientCreateDatasetResponseTypeDef:
        """
        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset)
        """

    def create_dataset_content(self, datasetName: str) -> ClientCreateDatasetContentResponseTypeDef:
        """
        [Client.create_dataset_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset_content)
        """

    def create_datastore(
        self,
        datastoreName: str,
        datastoreStorage: ClientCreateDatastoreDatastoreStorageTypeDef = None,
        retentionPeriod: ClientCreateDatastoreRetentionPeriodTypeDef = None,
        tags: List[ClientCreateDatastoreTagsTypeDef] = None,
    ) -> ClientCreateDatastoreResponseTypeDef:
        """
        [Client.create_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.create_datastore)
        """

    def create_pipeline(
        self,
        pipelineName: str,
        pipelineActivities: List[ClientCreatePipelinePipelineActivitiesTypeDef],
        tags: List[ClientCreatePipelineTagsTypeDef] = None,
    ) -> ClientCreatePipelineResponseTypeDef:
        """
        [Client.create_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.create_pipeline)
        """

    def delete_channel(self, channelName: str) -> None:
        """
        [Client.delete_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_channel)
        """

    def delete_dataset(self, datasetName: str) -> None:
        """
        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset)
        """

    def delete_dataset_content(self, datasetName: str, versionId: str = None) -> None:
        """
        [Client.delete_dataset_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset_content)
        """

    def delete_datastore(self, datastoreName: str) -> None:
        """
        [Client.delete_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_datastore)
        """

    def delete_pipeline(self, pipelineName: str) -> None:
        """
        [Client.delete_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_pipeline)
        """

    def describe_channel(
        self, channelName: str, includeStatistics: bool = None
    ) -> ClientDescribeChannelResponseTypeDef:
        """
        [Client.describe_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_channel)
        """

    def describe_dataset(self, datasetName: str) -> ClientDescribeDatasetResponseTypeDef:
        """
        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_dataset)
        """

    def describe_datastore(
        self, datastoreName: str, includeStatistics: bool = None
    ) -> ClientDescribeDatastoreResponseTypeDef:
        """
        [Client.describe_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_datastore)
        """

    def describe_logging_options(
        self, *args: Any, **kwargs: Any
    ) -> ClientDescribeLoggingOptionsResponseTypeDef:
        """
        [Client.describe_logging_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_logging_options)
        """

    def describe_pipeline(self, pipelineName: str) -> ClientDescribePipelineResponseTypeDef:
        """
        [Client.describe_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_pipeline)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> None:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.generate_presigned_url)
        """

    def get_dataset_content(
        self, datasetName: str, versionId: str = None
    ) -> ClientGetDatasetContentResponseTypeDef:
        """
        [Client.get_dataset_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.get_dataset_content)
        """

    def list_channels(
        self, nextToken: str = None, maxResults: int = None
    ) -> ClientListChannelsResponseTypeDef:
        """
        [Client.list_channels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.list_channels)
        """

    def list_dataset_contents(
        self,
        datasetName: str,
        nextToken: str = None,
        maxResults: int = None,
        scheduledOnOrAfter: datetime = None,
        scheduledBefore: datetime = None,
    ) -> ClientListDatasetContentsResponseTypeDef:
        """
        [Client.list_dataset_contents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.list_dataset_contents)
        """

    def list_datasets(
        self, nextToken: str = None, maxResults: int = None
    ) -> ClientListDatasetsResponseTypeDef:
        """
        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datasets)
        """

    def list_datastores(
        self, nextToken: str = None, maxResults: int = None
    ) -> ClientListDatastoresResponseTypeDef:
        """
        [Client.list_datastores documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datastores)
        """

    def list_pipelines(
        self, nextToken: str = None, maxResults: int = None
    ) -> ClientListPipelinesResponseTypeDef:
        """
        [Client.list_pipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.list_pipelines)
        """

    def list_tags_for_resource(self, resourceArn: str) -> ClientListTagsForResourceResponseTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.list_tags_for_resource)
        """

    def put_logging_options(
        self, loggingOptions: ClientPutLoggingOptionsLoggingOptionsTypeDef
    ) -> None:
        """
        [Client.put_logging_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.put_logging_options)
        """

    def run_pipeline_activity(
        self,
        pipelineActivity: ClientRunPipelineActivityPipelineActivityTypeDef,
        payloads: List[bytes],
    ) -> ClientRunPipelineActivityResponseTypeDef:
        """
        [Client.run_pipeline_activity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.run_pipeline_activity)
        """

    def sample_channel_data(
        self,
        channelName: str,
        maxMessages: int = None,
        startTime: datetime = None,
        endTime: datetime = None,
    ) -> ClientSampleChannelDataResponseTypeDef:
        """
        [Client.sample_channel_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.sample_channel_data)
        """

    def start_pipeline_reprocessing(
        self, pipelineName: str, startTime: datetime = None, endTime: datetime = None
    ) -> ClientStartPipelineReprocessingResponseTypeDef:
        """
        [Client.start_pipeline_reprocessing documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.start_pipeline_reprocessing)
        """

    def tag_resource(
        self, resourceArn: str, tags: List[ClientTagResourceTagsTypeDef]
    ) -> Dict[str, Any]:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.tag_resource)
        """

    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.untag_resource)
        """

    def update_channel(
        self,
        channelName: str,
        channelStorage: ClientUpdateChannelChannelStorageTypeDef = None,
        retentionPeriod: ClientUpdateChannelRetentionPeriodTypeDef = None,
    ) -> None:
        """
        [Client.update_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.update_channel)
        """

    def update_dataset(
        self,
        datasetName: str,
        actions: List[ClientUpdateDatasetActionsTypeDef],
        triggers: List[ClientUpdateDatasetTriggersTypeDef] = None,
        contentDeliveryRules: List[ClientUpdateDatasetContentDeliveryRulesTypeDef] = None,
        retentionPeriod: ClientUpdateDatasetRetentionPeriodTypeDef = None,
        versioningConfiguration: ClientUpdateDatasetVersioningConfigurationTypeDef = None,
    ) -> None:
        """
        [Client.update_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.update_dataset)
        """

    def update_datastore(
        self,
        datastoreName: str,
        retentionPeriod: ClientUpdateDatastoreRetentionPeriodTypeDef = None,
        datastoreStorage: ClientUpdateDatastoreDatastoreStorageTypeDef = None,
    ) -> None:
        """
        [Client.update_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.update_datastore)
        """

    def update_pipeline(
        self,
        pipelineName: str,
        pipelineActivities: List[ClientUpdatePipelinePipelineActivitiesTypeDef],
    ) -> None:
        """
        [Client.update_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Client.update_pipeline)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_channels"]
    ) -> paginator_scope.ListChannelsPaginator:
        """
        [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_dataset_contents"]
    ) -> paginator_scope.ListDatasetContentsPaginator:
        """
        [Paginator.ListDatasetContents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_datasets"]
    ) -> paginator_scope.ListDatasetsPaginator:
        """
        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_datastores"]
    ) -> paginator_scope.ListDatastoresPaginator:
        """
        [Paginator.ListDatastores documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_pipelines"]
    ) -> paginator_scope.ListPipelinesPaginator:
        """
        [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.2/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
        """


class Exceptions:
    ClientError: Boto3ClientError
    InternalFailureException: Boto3ClientError
    InvalidRequestException: Boto3ClientError
    LimitExceededException: Boto3ClientError
    ResourceAlreadyExistsException: Boto3ClientError
    ResourceNotFoundException: Boto3ClientError
    ServiceUnavailableException: Boto3ClientError
    ThrottlingException: Boto3ClientError
